currency_from_cstr

Function currency_from_cstr 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn currency_from_cstr( code_ptr: *const c_char, ) -> Currency
Converts a C string pointer to a Currency for FFI.

Panics

Panics if the provided code string is invalid or not found (unwrap).

Safety

Assumes code_ptr is a valid NUL-terminated UTF-8 C string pointer.